@@ -2,7 +2,7 @@
 
 Generator::Map Generator::s_insert =
 {
-    {"actioncases",                 &Generator::actionCases},
+    {"executeactioncases",          &Generator::executeActionCases},
     {"lex",                         &Generator::lex},
     {"scanner.h",                   &Generator::scannerH},
     {"scannerobject",               &Generator::scannerObject},
@@ -11,24 +11,26 @@ Generator::Map Generator::s_insert =
     {"class.ih",                    &Generator::classIH},
     {"debug",                       &Generator::debug},
     {"debugdecl",                   &Generator::debugDecl},
-    {"debuginit",                   &Generator::debugInit},
     {"debugfunctions",              &Generator::debugFunctions},
     {"debugincludes",               &Generator::debugIncludes},
     {"debuglookup",                 &Generator::debugLookup},
-    {"defaultactionreturn",         &Generator::defaultActionReturn},
     {"errorverbose",                &Generator::errorVerbose},
+    {"idoftag",                     &Generator::idOfTag},
     {"namespace-open",              &Generator::namespaceOpen},
     {"namespace-close",             &Generator::namespaceClose},
     {"namespace-use",               &Generator::namespaceUse},
+    {"polyincludes",                &Generator::polyIncludes},
     {"polymorphic",                 &Generator::polymorphic},
-    {"polymorphicInline",           &Generator::polymorphicInline},
+    {"polymorphicCode",             &Generator::polymorphicCode},
     {"polymorphicSpecializations",  &Generator::polymorphicSpecializations},
     {"preincludes",                 &Generator::preIncludes},
     {"print",                       &Generator::print},
     {"requiredtokens",              &Generator::requiredTokens},
+    {"actioncases",                 &Generator::actionCases},
     {"staticdata",                  &Generator::staticData},
     {"threading",                   &Generator::threading},
     {"tokens",                      &Generator::tokens},
+    {"warnTagMismatches",           &Generator::warnTagMismatches},
     {"LTYPE",                       &Generator::ltype},
     {"LTYPEdata",                   &Generator::ltypeData},
     {"LTYPEpop",                    &Generator::ltypePop},
