@@ -2,7 +2,7 @@
 
 void Generator::debug(ostream &out) const
 {
-    if (!d_debug)
+    if (!d_genDebug)
         return;
 
     key(out);
