@@ -40,9 +40,9 @@ class Generator
     mutable size_t d_indent;
 
     mutable std::string d_line;
-    bool d_debug;
+    bool d_genDebug;
     bool d_printTokens;
-    
+
     std::unordered_map<std::string, std::string> const &d_polymorphic; 
 
     mutable Writer d_writer;                // maintains its own const-ness
@@ -94,11 +94,12 @@ class Generator
         void debug(std::ostream &out) const;
         void debugIncludes(std::ostream &out) const;
         void debugFunctions(std::ostream &out) const;
-        void debugInit(std::ostream &out) const;
         void debugDecl(std::ostream &out) const;
         void debugLookup(std::ostream &out) const;
         void defaultActionReturn(std::ostream &out) const;
         void errorVerbose(std::ostream &out) const;
+        void executeActionCases(std::ostream &out) const;
+        void idOfTag(std::ostream &out) const;
         void lex(std::ostream &out) const;
         void ltype(std::ostream &out) const;
         void ltypeData(std::ostream &out) const;
@@ -110,7 +111,8 @@ class Generator
         void namespaceOpen(std::ostream &out) const;
         void namespaceUse(std::ostream &out) const;
         void polymorphic(std::ostream &out) const;
-        void polymorphicInline(std::ostream &out) const;
+        void polyIncludes(std::ostream &out) const;
+        void polymorphicCode(std::ostream &out) const;
         void polymorphicSpecializations(std::ostream &out) const;
         void preIncludes(std::ostream &out) const;
         void print(std::ostream &out) const;
@@ -121,6 +123,7 @@ class Generator
         void stype(std::ostream &out) const;
         void threading(std::ostream &out) const;
         void tokens(std::ostream &out) const;
+        void warnTagMismatches(std::ostream &out) const;
 
         void ifInsertStype(bool &accept) const;
         void ifPrintTokens(bool &accept) const;
