@@ -3,85 +3,118 @@
 
 #include <string>
 #include <set>
+#include <unordered_map>
 
 namespace FBB
 {
     class Arg;
 }
 
-class Options
+struct Options
 {
-    enum PathType
+    enum Value
     {
-        FILENAME,
-        PATHNAME
+        UNKNOWN = 0,
+        OFF     = 1 << 0,
+        ON      = 1 << 1,
+        QUIET   = 1 << 2,   // do not show warnings
+        WARN    = 1 << 3,   // show warnings
+        STD     = 1 << 4,   // do always $$ = $1, no warns
     };
 
-    FBB::Arg &d_arg;
+    struct OptInfo
+    {
+        Value      value;
+        std::string filename;
+        size_t      lineNr;
+    };
 
-    std::string const *d_matched;
+    private:
+        enum PathType
+        {
+            FILENAME,
+            PATHNAME
+        };
 
-    std::string d_fileName;                 // the name of the current file
-    size_t d_lineNr;                        // the current line nr.
+        FBB::Arg &d_arg;
+    
+        std::string const *d_matched;
+    
+        // The following three data members get their final values in 
+        // setAccessorVariables
 
-    bool        d_debug;
-    bool        d_errorVerbose;
-    bool        d_flex;
-    bool        d_lines;
-    bool        d_lspNeeded;
-    bool        d_printTokens;
-    bool        d_polymorphic;
-    bool        d_strongTags;
+                            // Resulting values: ON, OFF
+        OptInfo d_constructorChecks{OFF, "", 0};
 
-    size_t      d_requiredTokens;
+                            // Resulting values: ON, OFF
+        OptInfo d_tagMismatches{ON, "", 0};
 
-    std::set<std::string> d_warnOptions;    // contains the names of options 
+                            // Resulting values: OFF, QUIET, WARN, STD
+        OptInfo d_defaultActions{UNKNOWN, "", 0};
+
+        bool        d_genDebug          = false;
+        bool        d_errorVerbose      = false;
+        bool        d_flex              = false;
+        bool        d_lines             = true;
+        bool        d_lspNeeded         = false;
+        bool        d_polymorphic       = false;
+        bool        d_printTokens       = false;
+        bool        d_strongTags        = true;
+    
+        size_t      d_requiredTokens = 0;
+        size_t      d_stackExpansion = 0;
+
+        std::set<std::string> d_warnOptions;// contains the names of options 
                                             // for which Generator may warn
                                             // if specified for already
                                             // existing .h or .ih files
 
-    std::string d_baseClassHeader;
-    std::string d_baseClassSkeleton;
-    std::string d_polymorphicInline;
-    std::string d_polymorphicInlineSkeleton;
-    std::string d_polymorphicSkeleton;
-    std::string d_classHeader;
-    std::string d_className;
-    std::string d_classSkeleton;
-    std::string d_genericFilename;
-    std::string d_implementationHeader;
-    std::string d_implementationSkeleton;
-    std::string d_locationDecl;
-    std::string d_nameSpace;
-    std::string d_parsefunSkeleton;
-    std::string d_parsefunSource;
-    std::string d_preInclude;
-    std::string d_scannerInclude;
-    std::string d_scannerMatchedTextFunction;
-    std::string d_scannerTokenFunction;
-    std::string d_scannerClassName;
-    std::string d_skeletonDirectory;
-    std::string d_stackDecl;
-    std::string d_targetDirectory;
-    std::string d_verboseName;
+        std::string d_baseClassHeader;
+        std::string d_baseClassSkeleton;
+        std::string d_polymorphicCodeSkeleton;
+        std::string d_polymorphicInline;
+        std::string d_polymorphicSkeleton;
+        std::string d_classHeader;
+        std::string d_className;
+        std::string d_classSkeleton;
+        std::string d_genericFilename;
+        std::string d_implementationHeader;
+        std::string d_implementationSkeleton;
+        std::string d_locationDecl;
+        std::string d_nameSpace;
+        std::string d_parsefunSkeleton;
+        std::string d_parsefunSource;
+        std::string d_preInclude;
+        std::string d_scannerInclude;
+        std::string d_scannerMatchedTextFunction;
+        std::string d_scannerTokenFunction;
+        std::string d_scannerClassName;
+        std::string d_skeletonDirectory;
+        std::string d_stackDecl;
+        std::string d_targetDirectory;
+        std::string d_verboseName;
 
-    static char s_defaultBaseClassSkeleton[];
-    static char s_defaultPolymorphicInlineSkeleton[];
-    static char s_defaultPolymorphicSkeleton[];
-    static char s_defaultClassName[];
-    static char s_defaultClassSkeleton[];
-    static char s_defaultImplementationSkeleton[];
-    static char s_defaultParsefunSkeleton[];
-    static char s_defaultParsefunSource[];
-    static char s_defaultSkeletonDirectory[];
-    static char s_defaultTargetDirectory[];
-    static char s_defaultScannerClassName[];
-    static char s_defaultScannerMatchedTextFunction[];
-    static char s_defaultScannerTokenFunction[];
-    static char s_YYText[];
-    static char s_yylex[];
+        static size_t s_defaultStackExpansion;
+    
+        static char s_defaultBaseClassSkeleton[];
+        static char s_defaultPolymorphicCodeSkeleton[];
+        static char s_defaultPolymorphicSkeleton[];
+        static char s_defaultClassName[];
+        static char s_defaultClassSkeleton[];
+        static char s_defaultImplementationSkeleton[];
+        static char s_defaultParsefunSkeleton[];
+        static char s_defaultParsefunSource[];
+        static char s_defaultSkeletonDirectory[];
+        static char s_defaultTargetDirectory[];
+        static char s_defaultScannerClassName[];
+        static char s_defaultScannerMatchedTextFunction[];
+        static char s_defaultScannerTokenFunction[];
+        static char s_YYText[];
+        static char s_yylex[];
+    
+        static std::unordered_map<std::string, Value> s_value;
 
-    static Options *s_options;
+        static Options *s_options;
 
     public:
         static Options &instance();
@@ -90,15 +123,16 @@ class Options
 
         void setMatched(std::string const &matched);
 
+        void setParsingOptions();
+
         void setAccessorVariables();
 
         bool specified(std::string const &option) const;
 
         void setBaseClassHeader();
-        void setBaseClassSkeleton();
         void setClassHeader();
         void setClassName();
-        void setDebug();
+        void setGenDebug();
         void setErrorVerbose();
         void setFlex();
         void setGenericFilename();
@@ -109,20 +143,26 @@ class Options
         void setNamespace();
         void setParsefunSource();
         void setPolymorphicDecl();
-        void setPolymorphicInlineSkeleton();
-        void setPolymorphicSkeleton();
-        void setPrintTokens();
         void setPreInclude();
+        void setPrintTokens();
         void setRequiredTokens(size_t nRequiredTokens);
         void setScannerClassName();
         void setScannerInclude();
         void setScannerMatchedTextFunction();
         void setScannerTokenFunction();
-        void setSkeletonDirectory();
+        void setStackExpansion(size_t nr);
         void setStype();
         void setTargetDirectory();
         void setUnionDecl(std::string const &block);
         void setVerbosity();            // Prepare Msg for verbose output
+
+        void setTagMismatches(std::string const &request, 
+                                std::string const &filename, size_t lineNr);
+        void setDefaultAction(std::string const &request, 
+                                std::string const &filename, size_t lineNr);
+        void setConstructorChecks(std::string const &request,
+                                std::string const &filename, size_t lineNr);
+
         void unsetLines();
         void unsetStrongTags();
 
@@ -130,14 +170,20 @@ class Options
 
 
         bool printTokens() const;
-        bool debug() const;
+        bool genDebug() const;
+
         bool errorVerbose() const;
         bool lines() const;
         bool lspNeeded() const;
         bool polymorphic() const;
         bool strongTags() const;
 
+        OptInfo const &tagMismatches() const;
+        OptInfo const &constructorChecks() const;  
+        OptInfo const &defaultActions() const;
+
         size_t requiredTokens() const;
+        size_t stackExpansion() const;
 
         std::string const &baseClassSkeleton() const;
         std::string const &baseClassHeader() const;
@@ -152,7 +198,7 @@ class Options
         std::string const &parseSkeleton() const;
         std::string const &parseSource() const;
         std::string const &preInclude() const;
-        std::string const &polymorphicInlineSkeleton() const;
+        std::string const &polymorphicCodeSkeleton() const;
         std::string const &polymorphicSkeleton() const;
         std::string const &scannerClassName() const;
         std::string const &scannerInclude() const;
@@ -193,11 +239,29 @@ class Options
                       char const *optionName);
 
         bool isFirstStypeDefinition() const;
+
+        static Value valueOf(std::string const &key, Value byDefault, 
+                                unsigned mask = ~0);
 };
 
-inline bool Options::debug() const
+inline bool Options::genDebug() const
 {
-    return d_debug;
+    return d_genDebug;
+}
+
+inline Options::OptInfo const &Options::defaultActions() const
+{
+    return d_defaultActions;
+}
+
+inline Options::OptInfo const &Options::tagMismatches() const
+{
+    return d_tagMismatches;
+}
+
+inline Options::OptInfo const &Options::constructorChecks() const
+{
+    return d_constructorChecks;
 }
 
 inline std::string const &Options::baseClassHeader() const
@@ -280,9 +344,9 @@ inline std::string const &Options::parseSource() const
     return d_parsefunSource;
 }
 
-inline std::string const &Options::polymorphicInlineSkeleton() const
+inline std::string const &Options::polymorphicCodeSkeleton() const
 {
-    return d_polymorphicInlineSkeleton;
+    return d_polymorphicCodeSkeleton;
 }
 
 inline std::string const &Options::polymorphicSkeleton() const
@@ -305,6 +369,11 @@ inline size_t Options::requiredTokens() const
     return d_requiredTokens;
 }
 
+inline size_t Options::stackExpansion() const
+{
+    return d_stackExpansion == 0 ? s_defaultStackExpansion : d_stackExpansion;
+}
+
 inline std::string const &Options::scannerClassName() const
 {
     return d_scannerClassName;
@@ -330,11 +399,6 @@ inline void Options::setBaseClassHeader()
     assign(&d_baseClassHeader, FILENAME, "baseclass-header");
 }
 
-inline void Options::setBaseClassSkeleton()
-{
-    assign(&d_baseClassSkeleton, PATHNAME, "baseclass-skeleton");
-}
-
 inline void Options::setClassHeader()
 {
     assign(&d_classHeader, FILENAME, "class-header");
@@ -350,9 +414,9 @@ inline void Options::setErrorVerbose()
     d_errorVerbose = true;
 }
 
-inline void Options::setDebug()
+inline void Options::setGenDebug()
 {
-    d_debug = true;
+    d_genDebug = true;
 }
 
 inline void Options::setGenericFilename()
@@ -395,17 +459,6 @@ inline void Options::setParsefunSource()
     assign(&d_parsefunSource, FILENAME, "parsefun-source");
 }
 
-inline void Options::setPolymorphicInlineSkeleton()
-{
-    assign(&d_polymorphicInlineSkeleton, 
-                            PATHNAME, "polymorphic-inline-skeleton");
-}
-
-inline void Options::setPolymorphicSkeleton()
-{
-    assign(&d_polymorphicSkeleton, PATHNAME, "polymorphic-skeleton");
-}
-
 inline void Options::setPreInclude()
 {
     assign(&d_preInclude, PATHNAME, "baseclass-preinclude");
@@ -432,11 +485,6 @@ inline void Options::setScannerTokenFunction()
     assign(&d_scannerTokenFunction, FILENAME, "scanner-token-function");
 }
 
-inline void Options::setSkeletonDirectory()
-{
-    assign(&d_skeletonDirectory, PATHNAME, "skeleton-directory (-S)");
-}
-
 inline void Options::setTargetDirectory()
 {
     assign(&d_targetDirectory, PATHNAME, "target-directory");
