@@ -1,11 +1,13 @@
 #ifndef _INCLUDED_RULES_
 #define _INCLUDED_RULES_
 
+#include <iostream>
+
 #include <vector>
 #include <set>
-#include <map>
 #include <string>
 #include <algorithm>
+#include <unordered_map>
 
 #include "../block/block.h"
 #include "../terminal/terminal.h"
@@ -18,6 +20,9 @@
     // iterators into the symbol table
 class Rules
 { 
+    bool d_defaultAction;       // last action was default action:
+                                // requires line update at the next
+                                // rule definition
     public:
             // For each rule, maintain a record of file/line combinations
             // indicating where the rule was first seen. This allows me to
@@ -27,8 +32,14 @@ class Rules
             // unexpected conflicts
         typedef std::pair<std::string, size_t> FileInfo;
 
+        //FBB: 20160412 - see also sethiddenaction.cc for the use
+        //                of the 90000 line number flag that was used to flag
+        //                a hidden action. Apparently it was nowhere used
+        //                so I decided not to use it anymore.
+
     private:
-        typedef std::map<NonTerminal const *, FileInfo> NFileInfoMap;
+        typedef std::unordered_map<NonTerminal const *, FileInfo> 
+                                                            NFileInfoMap;
     
         Terminal::Vector d_terminal;        // the vector holding information 
                                             // about defined terminal symbols
@@ -65,7 +76,10 @@ class Rules
         static Symbol *s_startSymbol;       // derived from the initial N or
                                             // from the N defined as the
                                             // star tsymbol by
-                                            // augmentGrammar(). 
+                                            // augmentGrammar().
+
+        static size_t s_lastLineNr;         // last received line nr, used by
+                                            // setHiddenAction()
     
     public:
         Rules();
@@ -85,7 +99,8 @@ class Rules
                 // add the symbol as the next element of the 
                 // rule-production that's currently being defined. 
 
-        void addProduction();
+        void updateDefaultActionLineNr(size_t lineNr);
+        void addProduction(size_t lineNr);
                 // add a new production to the set of productions of the
                 // rule currently being defined
 
@@ -127,13 +142,12 @@ class Rules
         size_t nElements() const;
 
         void determineFirst();
-        void determineFollow();
 
         bool hasRules() const;
 
                 // associate an action with the currently defined rule
                 // production 
-        void setAction(Block const &block);
+        void setAction(Block const &block, bool defaultAction = false);
 
         void setHiddenAction(Block const &block);
 
@@ -150,7 +164,6 @@ class Rules
                 // production to the precedence of the given terminal.
 
         void showFirst() const;         // show the First-sets
-        void showFollow() const;        // show the Follow-sets
 
         void showTerminals() const;     // show symbolic terminals and their
                                         // values
@@ -175,19 +188,10 @@ class Rules
         void termToNonterm(Symbol *term, Symbol *nonTerm);
 
     private:
-        static void addFollowFromFirst(Production *production);
-        
-            // called by determineFollow() to process each NonTerminal
-            // It will in turn process each of the nonterminal's productions
-        static void addFirstToFollow(NonTerminal *nonTerminal);
-
-        void addFollowToFollow();
-        static void expandFollow(Production *production);
         static void updatePrecedence(Production *production, 
                                      Terminal::Vector const &tv);
 };
 
-
 inline Rules::Rules()
 :
     d_currentRule(0),
@@ -255,8 +259,9 @@ inline size_t Rules::nElements() const
     return d_currentProduction->size();
 }
 
-inline void Rules::setAction(Block const &block)
+inline void Rules::setAction(Block const &block, bool defaultAction)
 {
+    d_defaultAction = defaultAction;
     d_currentProduction->setAction(block);
 }
 
@@ -311,13 +316,6 @@ inline std::vector<Production const *> const &Rules::productions() const
            (vp);
 }
 
-inline void Rules::addFirstToFollow(NonTerminal *nonTerminal)
-{
-    for_each(nonTerminal->productions().begin(), 
-             nonTerminal->productions().end(), 
-            &addFollowFromFirst);
-}
-
 inline Rules::FileInfo const &Rules::fileInfo(NonTerminal const *nt) const
 {
     return d_location.find(nt)->second;
