@@ -56,12 +56,6 @@ namespace // anonymous
 {
     char const author[] = "Frank B. Brokken (f.b.brokken@rug.nl)";
 
-    enum 
-    {
-        STACK_EXPANSION = 5     // size to expand the state-stack with when
-                                // full
-    };
-
     enum ReservedTokens
     {
         PARSE_ACCEPT     = 0,   // `ACCEPT' TRANSITION
@@ -111,6 +105,8 @@ $insert 4 staticdata
 
 $insert namespace-open
 
+$insert polymorphicCode
+
 // If the parsing function call uses arguments, then provide an overloaded
 // function.  The code below doesn't rely on parameters, so no arguments are
 // required.  Furthermore, parse uses a function try block to allow us to do
@@ -119,9 +115,6 @@ $insert namespace-open
 
 \@Base::\@Base()
 :
-    d_stackIdx__(-1),
-$insert 4 debuginit
-    d_nErrors__(0),
 $insert 4 requiredtokens
     d_acceptedTokens__(d_requiredTokens__),
     d_token__(_UNDETERMINED_),
@@ -130,6 +123,18 @@ $insert 4 requiredtokens
 
 $insert debugfunctions
 
+void \@Base::setDebug(bool mode)
+{
+    d_actionCases__ = false;
+    d_debug__ = mode;
+}
+
+void \@Base::setDebug(DebugMode__ mode)
+{
+    d_actionCases__ = mode & ACTIONCASES;
+    d_debug__ =       mode & ON;
+}
+
 void \@::print__()
 {
 $insert print
@@ -142,25 +147,34 @@ void \@Base::clearin()
 
 void \@Base::push__(size_t state)
 {
-    if (static_cast<size_t>(d_stackIdx__ + 1) == d_stateStack__.size())
+    size_t currentSize = d_stateStack__.size();
+    if (static_cast<size_t>(d_stackIdx__ + 1) == currentSize)
     {
-        size_t newSize = d_stackIdx__ + STACK_EXPANSION;
+        size_t newSize = currentSize + STACK_EXPANSION__;
         d_stateStack__.resize(newSize);
-        d_valueStack__.resize(newSize);
 $insert 8 LTYPEresize
+        if (d_valueStack__.capacity() >= newSize)
+            d_valueStack__.resize(newSize);
+        else
+        {
+            std::vector<STYPE__> enlarged(newSize);
+            for (size_t idx = 0; idx != currentSize; ++idx)
+                enlarged[idx] = std::move(d_valueStack__[idx]);
+            d_valueStack__.swap(enlarged);
+        }
     }
     ++d_stackIdx__;
     d_stateStack__[d_stackIdx__] = d_state__ = state;
-    *(d_vsp__ = &d_valueStack__[d_stackIdx__]) = d_val__;
 $insert 4 LTYPEpush
 $insert 4 debug  "push(state " << state << stype__(", semantic TOS = ", d_val__, ")") << ')'
+    *(d_vsp__ = &d_valueStack__[d_stackIdx__]) = std::move(d_val__);
 }
 
 void \@Base::popToken__()
 {
     d_token__ = d_nextToken__;
 
-    d_val__ = d_nextVal__;
+    d_val__ = std::move(d_nextVal__);
     d_nextVal__ = STYPE__();
 
     d_nextToken__ = _UNDETERMINED_;
@@ -169,7 +183,7 @@ void \@Base::popToken__()
 void \@Base::pushToken__(int token)
 {
     d_nextToken__ = d_token__;
-    d_nextVal__ = d_val__;
+    d_nextVal__ = std::move(d_val__);
     d_token__ = token;
 }
      
@@ -187,7 +201,7 @@ $insert 8 debug "Terminating parse(): unrecoverable input error at token " << sy
     d_vsp__ = &d_valueStack__[d_stackIdx__];
 $insert 4 LTYPEpop
 $insert 4 debug "pop(): next state: " << d_state__ << ", token: " << symbol__(d_token__) +
-$insert 4 debug stype__("semantic: ", d_val__)
+$insert 4 debug stype__("semantic: ", *d_vsp__)
 }
 
 inline size_t \@Base::top__() const
@@ -201,18 +215,15 @@ try
     if (d_token__ != _UNDETERMINED_)
         pushToken__(d_token__);     // save an already available token
 
-                                    // save default non-nested block $$
-    if (int size = s_productionInfo[production].d_size)
-        d_val__ = d_vsp__[1 - size];
-
-$insert 4 debug "executeAction(): of rule " << production +
-$insert 4 debug  stype__(", semantic [TOS]: ", d_val__) << " ..."
+$insert 4 debug "executeAction of rule " << production +
+$insert 4 debug  stype__(", semantic [TOS]: ", *d_vsp__) << " ..."
+$insert executeactioncases
     switch (production)
     {
 $insert 8 actioncases
     }
 $insert 4 debug "... action of rule " << production << " completed" +
-$insert 4 debug  stype__(", semantic: ", d_val__)
+$insert 4 debug  stype__(", semantic: ", *d_vsp__)
 }
 catch (std::exception const &exc)
 {
