@@ -4,7 +4,7 @@
 #include <exception>
 #include <vector>
 #include <iostream>
-
+$insert polyincludes
 $insert preincludes
 $insert debugincludes
 
@@ -20,12 +20,19 @@ $insert polymorphic
 class \@Base
 {
     public:
+        enum DebugMode__
+        {
+            OFF           = 0,
+            ON            = 1 << 0,
+            ACTIONCASES   = 1 << 1
+        };
+
 $insert tokens
 $insert LTYPE
 $insert STYPE
 
     private:
-        int d_stackIdx__;
+        int d_stackIdx__ = -1;
         std::vector<size_t>   d_stateStack__;
         std::vector<STYPE__>  d_valueStack__;
 $insert LTYPEstack
@@ -41,8 +48,9 @@ $insert LTYPEstack
             DEFAULT_RECOVERY_MODE__,
             UNEXPECTED_TOKEN__,
         };
-        bool        d_debug__;
-        size_t      d_nErrors__;
+        bool        d_actionCases__ = false;
+        bool        d_debug__ = true;
+        size_t      d_nErrors__ = 0;
         size_t      d_requiredTokens__;
         size_t      d_acceptedTokens__;
         int         d_token__;
@@ -60,6 +68,7 @@ $insert debugdecl
         void ACCEPT() const;
         void ERROR() const;
         void clearin();
+        bool actionCases() const;
         bool debug() const;
         void pop__(size_t count = 1);
         void push__(size_t nextState);
@@ -71,16 +80,23 @@ $insert debugdecl
 
     public:
         void setDebug(bool mode);
+        void setDebug(DebugMode__ mode);
 }; 
 
+inline \@Base::DebugMode__ operator|(\@Base::DebugMode__ lhs, 
+                                     \@Base::DebugMode__ rhs)
+{
+    return static_cast<\@Base::DebugMode__>(static_cast<int>(lhs) | rhs);
+};
+
 inline bool \@Base::debug() const
 {
     return d_debug__;
 }
 
-inline void \@Base::setDebug(bool mode)
+inline bool \@Base::actionCases() const
 {
-    d_debug__ = mode;
+    return d_actionCases__;
 }
 
 inline void \@Base::ABORT() const
@@ -101,9 +117,14 @@ $insert 4 debug "ERROR(): Forced error condition"
     throw UNEXPECTED_TOKEN__;
 }
 
-$insert polymorphicInline
+inline \@Base::DebugMode__ operator&(\@Base::DebugMode__ lhs,
+                                     \@Base::DebugMode__ rhs)
+{
+    return static_cast<\@Base::DebugMode__>(
+            static_cast<int>(lhs) & rhs);
+}
 
-// As a convenience, when including ParserBase.h its symbols are available as
+// For convenience, when including ParserBase.h its symbols are available as
 // symbols in the class Parser, too.
 #define \@ \@Base
 
