@@ -1,6 +1,6 @@
 #include "state.ih"
 
-void State::notReducible(size_t idx)
+void State::notReducible(size_t idx)        // idx: item index in d_itemVector
 {
     Symbol const *symbol = d_itemVector[idx].symbolAtDot();
 
